@@ -348,6 +348,8 @@ link_io_thread_fn (gpointer data)
 	 * c) unref all leakable resources.
 	 */
 
+	link_connections_close ();
+
 	/* A tad of shutdown */
 	LINK_MUTEX_LOCK (link_cmd_queue_lock);
 	if (LINK_WAKEUP_WRITE >= 0) {
@@ -413,7 +415,9 @@ link_set_io_thread (gboolean io_in_thread)
 {
 	LinkCommand *cmd = g_new0 (LinkCommand, 1);
 
+#ifdef G_ENABLE_DEBUG
 	g_warning ("FIXME: guard from double entry");
+#endif
 
 	if (link_is_io_in_thread)
 		return;
